==> gradle-3.0-rc-2-all.zip: gradle-3.0-rc-2/src/ide/org/gradle/plugins/ide/internal/resolver/model/IdeProjectDependency.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.plugins.ide.internal.resolver.model;

import org.gradle.api.artifacts.component.ProjectComponentIdentifier;

public class IdeProjectDependency extends IdeDependency {
    private final ProjectComponentIdentifier projectId;
    private final String projectName;

    public IdeProjectDependency(ProjectComponentIdentifier projectId, String projectName) {
        this.projectId = projectId;
        this.projectName = projectName;
    }

    public IdeProjectDependency(ProjectComponentIdentifier projectId) {
        this.projectId = projectId;
        this.projectName = determineNameFromPath(projectId.getProjectPath());
    }

    public ProjectComponentIdentifier getProjectId() {
        return projectId;
    }

    public String getProjectPath() {
        return projectId.getProjectPath();
    }

    public String getProjectName() {
        return projectName;
    }

    private static String determineNameFromPath(String projectPath) {
        // TODO:DAZ This is less than ideal (currently only used for composite build dependencies)
        if (projectPath.endsWith("::")) {
            return projectPath.substring(0, projectPath.length() - 2);
        }
        int index = projectPath.lastIndexOf(':');
        return projectPath.substring(index + 1);
    }
}

==> gradle-3.2-rc-2-all.zip: gradle-3.2-rc-2/src/ide/org/gradle/plugins/ide/internal/resolver/model/IdeProjectDependency.java <==
/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.plugins.ide.internal.resolver.model;

import org.gradle.api.artifacts.component.ProjectComponentIdentifier;

public class IdeProjectDependency extends IdeDependency {
    private final ProjectComponentIdentifier projectId;
    private final String projectName;

    public IdeProjectDependency(ProjectComponentIdentifier projectId, String projectName) {
        this.projectId = projectId;
        this.projectName = projectName;
    }

    public IdeProjectDependency(ProjectComponentIdentifier projectId) {
        this.projectId = projectId;
        this.projectName = determineProjectName(projectId);
    }

    public ProjectComponentIdentifier getProjectId() {
        return projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    // TODO:DAZ Maybe add this to ProjectComponentIdentifier
    private static String determineProjectName(ProjectComponentIdentifier projectId) {
        assert !projectId.getBuild().isCurrentBuild();
        String projectPath = projectId.getProjectPath();
        if (projectPath.equals(":")) {
            return projectId.getBuild().getName();
        }
        int index = projectPath.lastIndexOf(':');
        return projectPath.substring(index + 1);
    }
}
